@@ -1,22 +1,16 @@
+from collections.abc import AsyncIterator, Iterator
 from contextlib import asynccontextmanager, contextmanager
 from contextvars import ContextVar
-from typing import Any, AsyncIterator, Iterator, NotRequired, TypedDict, cast
+from typing import Any, NotRequired, TypedDict, cast
 
-from psycopg import (
-    # Async
-    AsyncConnection as PgConnectionAsync,
-    AsyncCursor as PgCursorAsync,
-    AsyncTransaction,
-    # Sync
-    Connection as PgConnection,
-    Cursor as PgCursor,
-    Transaction,
-)
-from psycopg.rows import (
-    DictRow as PgDictRow,
-    dict_row as PgDictRowFactory,
-)
-from psycopg_pool import ConnectionPool, AsyncConnectionPool
+from psycopg import AsyncConnection as PgConnectionAsync  # Async
+from psycopg import AsyncCursor as PgCursorAsync
+from psycopg import AsyncTransaction, Transaction
+from psycopg import Connection as PgConnection  # Sync
+from psycopg import Cursor as PgCursor
+from psycopg.rows import DictRow as PgDictRow
+from psycopg.rows import dict_row as PgDictRowFactory
+from psycopg_pool import AsyncConnectionPool, ConnectionPool
 
 from database_wrapper import DatabaseBackend
 
@@ -27,7 +21,7 @@ PgConnectionTypeAsync = PgConnectionAsync[PgDictRow]
 PgCursorTypeAsync = PgCursorAsync[PgDictRow]
 
 
-class PgConfig(TypedDict):
+class PgsqlConfig(TypedDict):
     hostname: str
     port: NotRequired[int]
     username: str
@@ -41,7 +35,7 @@ class PgConfig(TypedDict):
     pool_kwargs: NotRequired[dict[str, Any]]
 
 
-class PgSQL(DatabaseBackend):
+class Pgsql(DatabaseBackend):
     """
     PostgreSQL database implementation.
 
@@ -51,7 +45,7 @@ class PgSQL(DatabaseBackend):
     Close is called automatically when class is destroyed.
 
     :param config: Configuration for PostgreSQL
-    :type config: PgConfig
+    :type config: PgsqlConfig
 
     Defaults:
         port = 5432
@@ -59,11 +53,15 @@ class PgSQL(DatabaseBackend):
 
     """
 
-    config: PgConfig
+    config: PgsqlConfig
 
     connection: PgConnectionType
     cursor: PgCursorType
 
+    ##################
+    ### Connection ###
+    ##################
+
     def open(self) -> None:
         # Free resources
         if hasattr(self, "connection") and self.connection:
@@ -92,15 +90,25 @@ class PgSQL(DatabaseBackend):
                 user=self.config["username"],
                 password=self.config["password"],
                 dbname=self.config["database"],
-                connect_timeout=self.connectionTimeout,
-                row_factory=PgDictRowFactory,  # type: ignore
+                connect_timeout=self.connection_timeout,
+                row_factory=PgDictRowFactory,
                 **self.config["kwargs"],
             ),
         )
         self.cursor = self.connection.cursor(row_factory=PgDictRowFactory)
 
         # Lets do some socket magic
-        self.fixSocketTimeouts(self.connection.fileno())
+        self.fix_socket_timeouts(self.connection.fileno())
+
+    def ping(self) -> bool:
+        try:
+            self.cursor.execute("SELECT 1")
+            self.cursor.fetchone()
+        except Exception as e:
+            self.logger.debug(f"Error while pinging the database: {e}")
+            return False
+
+        return True
 
     ####################
     ### Transactions ###
@@ -109,11 +117,11 @@ class PgSQL(DatabaseBackend):
     @contextmanager
     def transaction(
         self,
-        dbConn: PgConnectionType | None = None,
+        db_conn: PgConnectionType | None = None,
     ) -> Iterator[Transaction]:
         """Transaction context manager"""
-        if dbConn:
-            with dbConn.transaction() as trans:
+        if db_conn:
+            with db_conn.transaction() as trans:
                 yield trans
 
         assert self.connection, "Connection is not initialized"
@@ -124,7 +132,7 @@ class PgSQL(DatabaseBackend):
     ### Data ###
     ############
 
-    def affectedRows(self) -> int:
+    def affected_rows(self) -> int:
         assert self.cursor, "Cursor is not initialized"
 
         return self.cursor.rowcount
@@ -133,18 +141,18 @@ class PgSQL(DatabaseBackend):
         """Commit DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Commit DB queries")
+        self.logger.debug("Commit DB queries")
         self.connection.commit()
 
     def rollback(self) -> None:
         """Rollback DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Rollback DB queries")
+        self.logger.debug("Rollback DB queries")
         self.connection.rollback()
 
 
-class PgSQLAsync(DatabaseBackend):
+class PgsqlAsync(DatabaseBackend):
     """
     PostgreSQL database async implementation.
 
@@ -155,7 +163,7 @@ class PgSQLAsync(DatabaseBackend):
     ! You need to call it manually in async environment.
 
     :param config: Configuration for PostgreSQL
-    :type config: PgConfig
+    :type config: PgsqlConfig
 
     Defaults:
         port = 5432
@@ -163,7 +171,7 @@ class PgSQLAsync(DatabaseBackend):
 
     """
 
-    config: PgConfig
+    config: PgsqlConfig
 
     connection: PgConnectionTypeAsync
     cursor: PgCursorTypeAsync
@@ -201,14 +209,14 @@ class PgSQLAsync(DatabaseBackend):
             user=self.config["username"],
             password=self.config["password"],
             dbname=self.config["database"],
-            connect_timeout=self.connectionTimeout,
-            row_factory=PgDictRowFactory,  # type: ignore
+            connect_timeout=self.connection_timeout,
+            row_factory=PgDictRowFactory,
             **self.config["kwargs"],
         )
         self.cursor = self.connection.cursor(row_factory=PgDictRowFactory)
 
         # Lets do some socket magic
-        self.fixSocketTimeouts(self.connection.fileno())
+        self.fix_socket_timeouts(self.connection.fileno())
 
     async def close(self) -> Any:
         """Close connections"""
@@ -220,6 +228,16 @@ class PgSQLAsync(DatabaseBackend):
             self.logger.debug("Closing connection")
             await self.connection.close()
 
+    async def ping(self) -> bool:
+        try:
+            await self.cursor.execute("SELECT 1")
+            await self.cursor.fetchone()
+        except Exception as e:
+            self.logger.debug(f"Error while pinging the database: {e}")
+            return False
+
+        return True
+
     ####################
     ### Transactions ###
     ####################
@@ -227,11 +245,11 @@ class PgSQLAsync(DatabaseBackend):
     @asynccontextmanager
     async def transaction(
         self,
-        dbConn: PgConnectionTypeAsync | None = None,
+        db_conn: PgConnectionTypeAsync | None = None,
     ) -> AsyncIterator[AsyncTransaction]:
         """Transaction context manager"""
-        if dbConn:
-            async with dbConn.transaction() as trans:
+        if db_conn:
+            async with db_conn.transaction() as trans:
                 yield trans
 
         assert self.connection, "Connection is not initialized"
@@ -242,7 +260,7 @@ class PgSQLAsync(DatabaseBackend):
     ### Data ###
     ############
 
-    def affectedRows(self) -> int:
+    def affected_rows(self) -> int:
         assert self.cursor, "Cursor is not initialized"
 
         return self.cursor.rowcount
@@ -251,40 +269,40 @@ class PgSQLAsync(DatabaseBackend):
         """Commit DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Commit DB queries")
+        self.logger.debug("Commit DB queries")
         await self.connection.commit()
 
     async def rollback(self) -> None:
         """Rollback DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Rollback DB queries")
+        self.logger.debug("Rollback DB queries")
         await self.connection.rollback()
 
 
-class PgSQLWithPooling(DatabaseBackend):
+class PgsqlWithPooling(DatabaseBackend):
     """
     PostgreSQL database implementation with connection pooling.
 
     Instance is created without actually connecting to the database.
-    When you are ready to connect, call openPool() method.
+    When you are ready to connect, call open_pool() method.
 
-    Then you can use newConnection() to get connection from the pool and
-    returnConnection() to return it back.
+    Then you can use new_connection() to get connection from the pool and
+    return_connection() to return it back.
     Or use context manager to get connection and return it back automatically,
     for example:
 
-        pool = PgSQLWithPooling(config)
-        pool.openPool()
+        pool = PgsqlWithPooling(config)
+        pool.open_pool()
         with pool as (connection, cursor):
             cursor.execute("SELECT 1")
 
     :param config: Configuration for PostgreSQL
-    :type config: PgConfig
-    :param connectionTimeout: Connection timeout
-    :type connectionTimeout: int
-    :param instanceName: Name of the instance
-    :type instanceName: str
+    :type config: PgsqlConfig
+    :param connection_timeout: Connection timeout
+    :type connection_timeout: int
+    :param instance_name: Name of the instance
+    :type instance_name: str
 
     Defaults:
         port = 5432
@@ -292,7 +310,7 @@ class PgSQLWithPooling(DatabaseBackend):
         maxconnections = 5
     """
 
-    config: PgConfig
+    config: PgsqlConfig
     """ Configuration """
 
     pool: ConnectionPool[PgConnectionType]
@@ -304,7 +322,7 @@ class PgSQLWithPooling(DatabaseBackend):
     cursor: PgCursorType | None
     """ Cursor to database """
 
-    contextConnection: ContextVar[tuple[PgConnectionType, PgCursorType] | None]
+    context_connection: ContextVar[tuple[PgConnectionType, PgCursorType] | None]
     """ Connection used in context manager """
 
     ########################
@@ -313,53 +331,53 @@ class PgSQLWithPooling(DatabaseBackend):
 
     def __init__(
         self,
-        dbConfig: PgConfig,
-        connectionTimeout: int = 5,
-        instanceName: str = "postgresql_pool",
+        db_config: PgsqlConfig,
+        connection_timeout: int = 5,
+        instance_name: str = "postgresql_pool",
     ) -> None:
         """
         Main concept here is that in init we do not connect to database,
         so that class instances can be safely made regardless of connection statuss.
 
-        Remember to call openPool() after creating instance to actually open the pool to the database
-        and also closePool() to close the pool.
+        Remember to call open_pool() after creating instance to actually open the pool to the database
+        and also close_pool() to close the pool.
         """
 
-        super().__init__(dbConfig, connectionTimeout, instanceName)
+        super().__init__(db_config, connection_timeout, instance_name)
 
         # Set defaults
-        if not "port" in self.config or not self.config["port"]:
+        if "port" not in self.config or not self.config["port"]:
             self.config["port"] = 5432
 
-        if not "ssl" in self.config or not self.config["ssl"]:
+        if "ssl" not in self.config or not self.config["ssl"]:
             self.config["ssl"] = "prefer"
 
-        if not "kwargs" in self.config or not self.config["kwargs"]:
+        if "kwargs" not in self.config or not self.config["kwargs"]:
             self.config["kwargs"] = {}
 
-        if not "autocommit" in self.config["kwargs"]:
+        if "autocommit" not in self.config["kwargs"]:
             self.config["kwargs"]["autocommit"] = True
 
         # Connection pooling defaults
-        if not "maxconnections" in self.config or not self.config["maxconnections"]:
+        if "maxconnections" not in self.config or not self.config["maxconnections"]:
             self.config["maxconnections"] = 5
 
-        if not "pool_kwargs" in self.config or not self.config["pool_kwargs"]:
+        if "pool_kwargs" not in self.config or not self.config["pool_kwargs"]:
             self.config["pool_kwargs"] = {}
 
-        connStr = (
+        conn_str = (
             f"postgresql://{self.config['username']}:{self.config['password']}@{self.config['hostname']}:{self.config['port']}"
-            f"/{self.config['database']}?connect_timeout={self.connectionTimeout}&application_name={self.name}"
+            f"/{self.config['database']}?connect_timeout={self.connection_timeout}&application_name={self.name}"
             f"&sslmode={self.config['ssl']}"
         )
         self.pool = ConnectionPool(
-            connStr,
+            conn_str,
             open=False,
             min_size=2,
             max_size=self.config["maxconnections"],
             max_lifetime=20 * 60,
             max_idle=400,
-            timeout=self.connectionTimeout,
+            timeout=self.connection_timeout,
             reconnect_timeout=0,
             num_workers=4,
             connection_class=PgConnectionType,
@@ -371,15 +389,15 @@ class PgSQLWithPooling(DatabaseBackend):
     ### Connection ###
     ##################
 
-    def openPool(self) -> None:
-        self.pool.open(wait=True, timeout=self.connectionTimeout)
+    def open_pool(self) -> None:
+        self.pool.open(wait=True, timeout=self.connection_timeout)
 
-    def closePool(self) -> None:
+    def close_pool(self) -> None:
         """Close Pool"""
 
-        if self.shutdownRequested.is_set():
+        if self.shutdown_requested.is_set():
             return
-        self.shutdownRequested.set()
+        self.shutdown_requested.set()
 
         # Close pool
         self.logger.debug("Closing connection pool")
@@ -393,11 +411,11 @@ class PgSQLWithPooling(DatabaseBackend):
             self.close()
 
         # Create new connection
-        res = self.newConnection()
+        res = self.new_connection()
         if res:
             (self.connection, self.cursor) = res
 
-    def newConnection(
+    def new_connection(
         self,
     ) -> tuple[PgConnectionType, PgCursorType] | None:
         assert self.pool, "Pool is not initialized"
@@ -407,14 +425,14 @@ class PgSQLWithPooling(DatabaseBackend):
 
         # Get connection from the pool
         tries = 0
-        while not self.shutdownRequested.is_set():
+        while not self.shutdown_requested.is_set():
             connection = None
             try:
-                connection = self.pool.getconn(timeout=self.connectionTimeout)
+                connection = self.pool.getconn(timeout=self.connection_timeout)
                 cursor = connection.cursor(row_factory=PgDictRowFactory)
 
                 # Lets do some socket magic
-                self.fixSocketTimeouts(connection.fileno())
+                self.fix_socket_timeouts(connection.fileno())
 
                 with connection.transaction():
                     cursor.execute("SELECT 1")
@@ -428,7 +446,7 @@ class PgSQLWithPooling(DatabaseBackend):
                     self.pool.putconn(connection)
 
                 self.logger.error(f"Error while getting connection from the pool: {e}")
-                self.shutdownRequested.wait(self.slowDownTimeout)
+                self.shutdown_requested.wait(self.slow_down_timeout)
                 tries += 1
                 if tries >= 3:
                     break
@@ -436,7 +454,7 @@ class PgSQLWithPooling(DatabaseBackend):
 
         return None
 
-    def returnConnection(self, connection: PgConnectionType) -> None:
+    def return_connection(self, connection: PgConnectionType) -> None:
         """Return connection to the pool"""
         assert self.pool, "Pool is not initialized"
 
@@ -459,11 +477,11 @@ class PgSQLWithPooling(DatabaseBackend):
         """Context manager"""
 
         # Lets set the context var so that it is set even if we fail to get connection
-        self.contextConnection.set(None)
+        self.context_connection.set(None)
 
-        res = self.newConnection()
+        res = self.new_connection()
         if res:
-            self.contextConnection.set(res)
+            self.context_connection.set(res)
             return res
 
         return (
@@ -474,12 +492,12 @@ class PgSQLWithPooling(DatabaseBackend):
     def __exit__(self, exc_type: Any, exc_value: Any, traceback: Any) -> None:
         """Context manager"""
 
-        testData = self.contextConnection.get()
-        if testData:
-            self.returnConnection(testData[0])
+        test_data = self.context_connection.get()
+        if test_data:
+            self.return_connection(test_data[0])
 
         # Reset context
-        self.contextConnection.set(None)
+        self.context_connection.set(None)
 
     ####################
     ### Transactions ###
@@ -488,11 +506,11 @@ class PgSQLWithPooling(DatabaseBackend):
     @contextmanager
     def transaction(
         self,
-        dbConn: PgConnectionType | None = None,
+        db_conn: PgConnectionType | None = None,
     ) -> Iterator[Transaction]:
         """Transaction context manager"""
-        if dbConn:
-            with dbConn.transaction() as trans:
+        if db_conn:
+            with db_conn.transaction() as trans:
                 yield trans
 
         assert self.connection, "Connection is not initialized"
@@ -503,7 +521,7 @@ class PgSQLWithPooling(DatabaseBackend):
     ### Data ###
     ############
 
-    def affectedRows(self) -> int:
+    def affected_rows(self) -> int:
         assert self.cursor, "Cursor is not initialized"
 
         return self.cursor.rowcount
@@ -512,45 +530,45 @@ class PgSQLWithPooling(DatabaseBackend):
         """Commit DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Commit DB queries")
+        self.logger.debug("Commit DB queries")
         self.connection.commit()
 
     def rollback(self) -> None:
         """Rollback DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Rollback DB queries")
+        self.logger.debug("Rollback DB queries")
         self.connection.rollback()
 
 
-class PgSQLWithPoolingAsync(DatabaseBackend):
+class PgsqlWithPoolingAsync(DatabaseBackend):
     """
     PostgreSQL database implementation with async connection pooling.
 
     Instance is created without actually connecting to the database.
-    When you are ready to connect, call await openPool() method.
+    When you are ready to connect, call await open_pool() method.
 
-    Then you can use newConnection() to get connection from the pool and
-    returnConnection() to return it back.
+    Then you can use new_connection() to get connection from the pool and
+    return_connection() to return it back.
 
     Or use context manager to get connection and return it back automatically,
     for example:
 
-        pool = PgSQLWithPoolingAsync(config)
-        await pool.openPool()
+        pool = PgsqlWithPoolingAsync(config)
+        await pool.open_pool()
         async with pool as (connection, cursor):
             await cursor.execute("SELECT 1")
 
 
     ! Note: Close is not called automatically when class is destroyed.
-    ! You need to call `await closePool()` manually in async environment.
+    ! You need to call `await close_pool()` manually in async environment.
 
     :param config: Configuration for PostgreSQL
-    :type config: PgConfig
-    :param connectionTimeout: Connection timeout
-    :type connectionTimeout: int
-    :param instanceName: Name of the instance
-    :type instanceName: str
+    :type config: PgsqlConfig
+    :param connection_timeout: Connection timeout
+    :type connection_timeout: int
+    :param instance_name: Name of the instance
+    :type instance_name: str
 
     Defaults:
         port = 5432
@@ -558,10 +576,10 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
         maxconnections = 5
     """
 
-    config: PgConfig
+    config: PgsqlConfig
     """ Configuration """
 
-    poolAsync: AsyncConnectionPool[PgConnectionTypeAsync]
+    pool_async: AsyncConnectionPool[PgConnectionTypeAsync]
     """ Connection pool """
 
     connection: PgConnectionTypeAsync | None
@@ -570,9 +588,7 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
     cursor: PgCursorTypeAsync | None
     """ Cursor to database """
 
-    contextConnectionAsync: ContextVar[
-        tuple[PgConnectionTypeAsync, PgCursorTypeAsync] | None
-    ]
+    context_connection_async: ContextVar[tuple[PgConnectionTypeAsync, PgCursorTypeAsync] | None]
     """ Connection used in async context manager """
 
     ########################
@@ -581,53 +597,53 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
 
     def __init__(
         self,
-        dbConfig: PgConfig,
-        connectionTimeout: int = 5,
-        instanceName: str = "async_postgresql",
+        db_config: PgsqlConfig,
+        connection_timeout: int = 5,
+        instance_name: str = "async_postgresql",
     ) -> None:
         """
         Main concept here is that in init we do not connect to database,
         so that class instances can be safely made regardless of connection statuss.
 
-        Remember to call await openPool() after creating instance to actually open the pool to the database
-        and also await closePool() to close the pool.
+        Remember to call await open_pool() after creating instance to actually open the pool to the database
+        and also await close_pool() to close the pool.
         """
 
-        super().__init__(dbConfig, connectionTimeout, instanceName)
+        super().__init__(db_config, connection_timeout, instance_name)
 
         # Set defaults
-        if not "port" in self.config or not self.config["port"]:
+        if "port" not in self.config or not self.config["port"]:
             self.config["port"] = 5432
 
-        if not "ssl" in self.config or not self.config["ssl"]:
+        if "ssl" not in self.config or not self.config["ssl"]:
             self.config["ssl"] = "prefer"
 
-        if not "kwargs" in self.config or not self.config["kwargs"]:
+        if "kwargs" not in self.config or not self.config["kwargs"]:
             self.config["kwargs"] = {}
 
-        if not "autocommit" in self.config["kwargs"]:
+        if "autocommit" not in self.config["kwargs"]:
             self.config["kwargs"]["autocommit"] = True
 
         # Connection pooling defaults
-        if not "maxconnections" in self.config or not self.config["maxconnections"]:
+        if "maxconnections" not in self.config or not self.config["maxconnections"]:
             self.config["maxconnections"] = 5
 
-        if not "pool_kwargs" in self.config or not self.config["pool_kwargs"]:
+        if "pool_kwargs" not in self.config or not self.config["pool_kwargs"]:
             self.config["pool_kwargs"] = {}
 
-        connStr = (
+        conn_str = (
             f"postgresql://{self.config['username']}:{self.config['password']}@{self.config['hostname']}:{self.config['port']}"
-            f"/{self.config['database']}?connect_timeout={self.connectionTimeout}&application_name={self.name}"
+            f"/{self.config['database']}?connect_timeout={self.connection_timeout}&application_name={self.name}"
             f"&sslmode={self.config['ssl']}"
         )
-        self.poolAsync = AsyncConnectionPool(
-            connStr,
+        self.pool_async = AsyncConnectionPool(
+            conn_str,
             open=False,
             min_size=2,
             max_size=self.config["maxconnections"],
             max_lifetime=20 * 60,
             max_idle=400,
-            timeout=self.connectionTimeout,
+            timeout=self.connection_timeout,
             reconnect_timeout=0,
             num_workers=4,
             connection_class=PgConnectionTypeAsync,
@@ -639,27 +655,27 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
         """Destructor"""
         del self.cursor
         del self.connection
-        del self.poolAsync
+        del self.pool_async
 
     ##################
     ### Connection ###
     ##################
 
-    async def openPool(self) -> None:
-        await self.poolAsync.open(wait=True, timeout=self.connectionTimeout)
+    async def open_pool(self) -> None:
+        await self.pool_async.open(wait=True, timeout=self.connection_timeout)
 
-    async def closePool(self) -> None:
+    async def close_pool(self) -> None:
         """Close Pool"""
 
-        if self.shutdownRequested.is_set():
+        if self.shutdown_requested.is_set():
             return
-        self.shutdownRequested.set()
+        self.shutdown_requested.set()
 
         # Close async pool
         self.logger.debug("Closing connection pool")
         await self.close()
-        if hasattr(self, "poolAsync") and self.poolAsync.closed is False:
-            await self.poolAsync.close()
+        if hasattr(self, "poolAsync") and self.pool_async.closed is False:
+            await self.pool_async.close()
 
     async def open(self) -> None:
         """Get connection from the pool and keep it in the class"""
@@ -667,7 +683,7 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
             await self.close()
 
         # Create new connection
-        res = await self.newConnection()
+        res = await self.new_connection()
         if res:
             (self.connection, self.cursor) = res
 
@@ -680,29 +696,27 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
             self.cursor = None
 
         if self.connection:
-            await self.returnConnection(self.connection)
+            await self.return_connection(self.connection)
             self.connection = None
 
-    async def newConnection(
+    async def new_connection(
         self,
     ) -> tuple[PgConnectionTypeAsync, PgCursorTypeAsync] | None:
-        assert self.poolAsync, "Async pool is not initialized"
+        assert self.pool_async, "Async pool is not initialized"
 
         # Log
         self.logger.debug("Getting connection from the pool")
 
         # Get connection from the pool
         tries = 0
-        while not self.shutdownRequested.is_set():
+        while not self.shutdown_requested.is_set():
             connection = None
             try:
-                connection = await self.poolAsync.getconn(
-                    timeout=self.connectionTimeout
-                )
+                connection = await self.pool_async.getconn(timeout=self.connection_timeout)
                 cursor = connection.cursor(row_factory=PgDictRowFactory)
 
                 # Lets do some socket magic
-                self.fixSocketTimeouts(connection.fileno())
+                self.fix_socket_timeouts(connection.fileno())
 
                 async with connection.transaction():
                     await cursor.execute("SELECT 1")
@@ -713,10 +727,10 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
             except Exception as e:
                 if connection:
                     await connection.close()
-                    await self.poolAsync.putconn(connection)
+                    await self.pool_async.putconn(connection)
 
                 self.logger.error(f"Error while getting connection from the pool: {e}")
-                self.shutdownRequested.wait(self.slowDownTimeout)
+                self.shutdown_requested.wait(self.slow_down_timeout)
                 tries += 1
                 if tries >= 3:
                     break
@@ -724,18 +738,18 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
 
         return None
 
-    async def returnConnection(self, connection: PgConnectionTypeAsync) -> None:
+    async def return_connection(self, connection: PgConnectionTypeAsync) -> None:
         """Return connection to the pool"""
-        assert self.poolAsync, "Async pool is not initialized"
+        assert self.pool_async, "Async pool is not initialized"
 
         # Log
         self.logger.debug("Putting connection back to the pool")
 
         # Put connection back to the pool
-        await self.poolAsync.putconn(connection)
+        await self.pool_async.putconn(connection)
 
         # Debug
-        self.logger.debug(self.poolAsync.get_stats())
+        self.logger.debug(self.pool_async.get_stats())
 
     ###############
     ### Context ###
@@ -747,11 +761,11 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
         """Context manager"""
 
         # Lets set the context var so that it is set even if we fail to get connection
-        self.contextConnectionAsync.set(None)
+        self.context_connection_async.set(None)
 
-        res = await self.newConnection()
+        res = await self.new_connection()
         if res:
-            self.contextConnectionAsync.set(res)
+            self.context_connection_async.set(res)
             return res
 
         return (
@@ -762,12 +776,12 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
     async def __aexit__(self, exc_type: Any, exc_value: Any, traceback: Any) -> None:
         """Context manager"""
 
-        testData = self.contextConnectionAsync.get()
-        if testData:
-            await self.returnConnection(testData[0])
+        test_data = self.context_connection_async.get()
+        if test_data:
+            await self.return_connection(test_data[0])
 
         # Reset context
-        self.contextConnectionAsync.set(None)
+        self.context_connection_async.set(None)
 
     ####################
     ### Transactions ###
@@ -776,11 +790,11 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
     @asynccontextmanager
     async def transaction(
         self,
-        dbConn: PgConnectionTypeAsync | None = None,
+        db_conn: PgConnectionTypeAsync | None = None,
     ) -> AsyncIterator[AsyncTransaction]:
         """Transaction context manager"""
-        if dbConn:
-            async with dbConn.transaction() as trans:
+        if db_conn:
+            async with db_conn.transaction() as trans:
                 yield trans
 
         assert self.connection, "Connection is not initialized"
@@ -791,7 +805,7 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
     ### Data ###
     ############
 
-    def affectedRows(self) -> int:
+    def affected_rows(self) -> int:
         assert self.cursor, "Cursor is not initialized"
 
         return self.cursor.rowcount
@@ -800,12 +814,12 @@ class PgSQLWithPoolingAsync(DatabaseBackend):
         """Commit DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Commit DB queries")
+        self.logger.debug("Commit DB queries")
         await self.connection.commit()
 
     async def rollback(self) -> None:
         """Rollback DB queries"""
         assert self.connection, "Connection is not initialized"
 
-        self.logger.debug(f"Rollback DB queries")
+        self.logger.debug("Rollback DB queries")
         await self.connection.rollback()
